@@ -8,12 +8,15 @@
 
 
 /*
- * Copyright (c) 2004 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  *
  * Revisions:
  *
+ *     01/09/09 [RCG]
+ *              - Patch from Jason White to fix Kerberos error.
+ *
  *     04/11/05 [RCG]
  *              - Add 'x' command-line option to disable XTND XMIT.
  *
@@ -508,7 +511,7 @@ char    **      argmessage;
 
 #ifdef     KERBEROS
     p->kerberos_service    = KERBEROS_SERVICE;
-    DEBUG_LOG1 ( p, "Set kerberos_service to %s", p-.kerberos_service );
+    DEBUG_LOG1 ( p, "Set kerberos_service to %s", p->.kerberos_service );
 #endif  /* KERBEROS */
 
 #ifdef    SERVER_MODE
