@@ -5,7 +5,7 @@
  */
  
 /*
- * Copyright (c) 2008 QUALCOMM Incorporated.  All rights reserved.
+ * Copyright (c) 2009 QUALCOMM Incorporated.  All rights reserved.
  * The file License.txt specifies the terms for use, modification,
  * and redistribution.
  */
@@ -82,6 +82,22 @@
 #endif /* SCRAM */
 
 
+/*
+ * Set a maximum file name (really path) length
+ */
+#ifdef    HAVE_LIMITS_H
+#  include <limits.h>
+#endif /* HAVE_LIMITS_H */
+#ifdef    HAVE_SYS_SYSLIMITS_H
+#  include <sys/syslimits.h>
+#endif /* HAVE_SYS_SYSLIMITS_H */
+#ifdef    PATH_MAX
+#  define MAXFILENAME     PATH_MAX
+#else
+#  define MAXFILENAME     256
+#endif /* PATH_MAX */
+
+
 #define QPOP_NAME "Qpopper"
 
 
@@ -94,7 +110,6 @@
 #define MAXDROPLEN      256
 #define MAXLINELEN      1024
 #define MAXMSGLINELEN   MAXLINELEN
-#define MAXFILENAME     256
 #define MAXCMDLEN       4
 #define MAXPARMCOUNT    5
 #define MAXPARMLEN      10
